/*
 * Copyright © 2024 Apple Inc. and the Pkl project authors. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.pkl.core.packages;

import java.util.Objects;
import org.pkl.core.util.Nullable;

public final class Checksums {
  private final String sha256;

  @Override
  public String toString() {
    return "pkl.Project#Checksums {sha256='" + sha256 + "'}";
  }

  public Checksums(String sha256) {
    this.sha256 = sha256;
  }

  public String getSha256() {
    return sha256;
  }

  @Override
  public boolean equals(@Nullable Object o) {
    if (this == o) {
      return true;
    }
    if (o == null || getClass() != o.getClass()) {
      return false;
    }
    Checksums that = (Checksums) o;
    return sha256.equals(that.sha256);
  }

  @Override
  public int hashCode() {
    return Objects.hash(getSha256());
  }
}
